#
# spec file for package python-aiodns
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


# DNS tests won't work in OBS
%bcond_with tests

%define skip_python2 1
%{?sle15_python_module_pythons}
Name:           python-aiodns
Version:        3.1.1
Release:        1.1
Summary:        Simple DNS resolver for asyncio
License:        MIT
Group:          Development/Libraries/Python
URL:            https://github.com/saghul/aiodns/releases
Source0:        https://github.com/saghul/aiodns/archive/refs/tags/v%{version}.tar.gz#/aiodns-%{version}.tar.gz
BuildRequires:  %{python_module setuptools}
Requires:       python-pycares >= 4.0.0
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
%if %{with tests}
BuildRequires:  %{python_module pycares}
BuildRequires:  python-typing
%endif
BuildArch:      noarch

%python_subpackages

%description
Simple DNS resolver for asyncio module.

%prep
%autosetup -p1 -n aiodns-%{version}

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}/aiodns/

%if %{with tests}
%check
%python_exec ./tests.py
%endif

%files %{python_files}
%doc ChangeLog README.rst
%license LICENSE
%{python_sitelib}/aiodns*

%changelog
* Thu Dec 14 2023 Petr Gajdos <pgajdos@suse.com>
- update to 3.1.1:
  * Add PEP-561 with py.typed
* Fri Apr 21 2023 Dirk Müller <dmueller@suse.com>
- add sle15_python_module_pythons (jsc#PED-68)
* Thu Apr 13 2023 Matej Cepl <mcepl@suse.com>
- Make calling of %%{sle15modernpython} optional.
* Wed Jun 16 2021 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 3.0.0
  * Release wheels and source to PyPI with GH actions
  * Try to make tests more resilient
  * Don't build universal wheels
  * Migrate CI to GH Actions
  * Fix TXT CHAOS test
  * Add support for CAA queries
  * Support Python >= 3.6
  * Bump pycares dependency
  * Drop tasks.py
  * Allow specifying dnsclass for queries
  * Set URL to https
  * Add license args in setup.py
  * Converted Type Annotations to Py3 syntax Closes
  * Only run mypy on cpython versions
  * Also fix all type errors with latest mypy - pycares seems to have
    no typing / stubs so lets ignore it via `mypy.ini`
  * setup: typing exists since Python 3.5
  * Fix type annotation of gethostbyname()
  * Updated README
- Drop patches for issues fixed upstream
  * python-aiodns-2.0.0-fix-typing-dependency.patch
* Thu Jul  9 2020 Matthias Fehring <buschmann23@opensuse.org>
- fix python-aiodns-2.0.0-fix-typing-dependency.patch and really
  apply it
* Thu Jul  9 2020 Matthias Fehring <buschmann23@opensuse.org>
- add python-aiodns-2.0.0-fix-typing-dependency.patch to fix wrong
  dependency to python-typing on python 3.5+ (gh#saghul/aiodns/issues/71)
* Thu Mar 21 2019 Ondřej Súkup <mimi.vx@gmail.com>
- update to 2.0.0
  * drop python2 support
  * Add support for ANY queries
* Fri Mar  1 2019 Ondřej Súkup <mimi.vx@gmail.com>
- update to 1.2.0
- Fix dependencies
  * Add support for Python 3.7
  * Fix CNAME test
  * Add examples with `async` and `await`
  * Fix Python version check
  * Add gethostbyaddr
* Fri May 11 2018 toddrme2178@gmail.com
- Don't forget python_module workaround.
* Fri Feb  9 2018 sleep_walker@opensuse.org
- put LICENSE with %%license
- make conditional tests (but disable by default because of OBS build
  isolation)
* Fri Feb  9 2018 sleep_walker@opensuse.org
- install LICENSE, ChangeLog and README
- improve spec file a bit
- add URL to source
- make it proper single spec python package
* Wed Feb  7 2018 sleep_walker@opensuse.org
- let there be python-aiodns
